@@ -23,7 +23,14 @@ from martian.error import GrokImportError
 from zope.interface.declarations import DescriptorAwareMetaClasses
 
 class subscribe:
+    """Declares that a function is to be registered as an event handler for the
+    specified objects.
 
+    Normally, an event handler is simply registered as a subscriber for the
+    event interface. In case of object events, the event handler is registered
+    as a subscriber for the object type and the event interface.
+
+    """
     def __init__(self, *args):
         self.subscribed = args
 
@@ -37,17 +44,25 @@ class subscribe:
             raise GrokImportError("@grok.subscribe requires at least one "
                                   "argument.")
 
+        # Add the function and subscribed interfaces to the
+        # grok.subscribers module annotation.
         subscribers = frame.f_locals.get('__grok_subscribers__', None)
         if subscribers is None:
             frame.f_locals['__grok_subscribers__'] = subscribers = []
         subscribers.append((function, self.subscribed))
 
-        # Also add __grok_adapts__ attribute to the function so that
-        # you can manually register the subscriber with, say,
-        # provideHandler.
+        # Also store the subscribed interfaces on the
+        # attribute__component_adapts__ for provideHandler to register
+        # the subscriber (in case you don't grok your package and
+        # register it manually)
         return zope.component.adapter(*self.subscribed)(function)
 
 class adapter(zope.component.adapter):
+    """Registers the function as an adapter for the specific interface.
+
+    The ``name`` argument must be a keyword argument and is optional. If given,
+    a named adapter is registered.
+    """
 
     # Override the z.c.adapter decorator to force sanity checking and
     # have better error reporting and add the ability to capture the name
@@ -59,18 +74,18 @@ class adapter(zope.component.adapter):
         if type(interfaces[0]) is types.FunctionType:
             raise GrokImportError(
                 "@grok.adapter requires at least one argument.")
-        
+
         self.name = u""
-        
+
         if kw:
             if 'name' in kw:
                 self.name = kw.pop('name')
             if kw:
                 raise GrokImportError(
                     "@grok.adapter got unexpected keyword arguments: %s" % ','.join(kw.keys()))
-        
+
         zope.component.adapter.__init__(self, *interfaces)
-    
+
     def __call__(self, ob):
         ob = zope.component.adapter.__call__(self, ob)
         if self.name:
@@ -78,6 +93,13 @@ class adapter(zope.component.adapter):
         return ob
 
 class implementer(zope.interface.implementer):
+    """Declares that the function implements a certain interface (or a number
+    of interfaces).
+
+    This is useful when a function serves as an object factory, e.g. as an
+    adapter.
+
+    """
 
     def __call__(self, ob):
         # XXX we do not have function grokkers (yet) so we put the annotation
@@ -87,10 +109,16 @@ class implementer(zope.interface.implementer):
         if adapters is None:
             frame.f_locals['__grok_adapters__'] = adapters = []
         adapters.append(ob)
+
         return zope.interface.implementer.__call__(self, ob)
 
 class provider:
+    """Declares that the function object provides a certain interface (or a
+    number of interfaces).
 
+    This is akin to calling directlyProvides() on the function object.
+
+    """
     def __init__(self, *interfaces):
         self.interfaces = interfaces
 
