@@ -43,7 +43,7 @@ class AdapterGrokker(martian.ClassGrokker):
     def execute(self, factory, config, context, provides, name, **kw):
         config.action(
             discriminator=('adapter', context, provides, name),
-            callable=component.provideAdapter,
+            callable=grokcore.component.provideAdapter,
             args=(factory, (context,), provides, name),
             )
         return True
@@ -63,7 +63,7 @@ class MultiAdapterGrokker(martian.ClassGrokker):
 
         config.action(
             discriminator=('adapter', for_, provides, name),
-            callable=component.provideAdapter,
+            callable=grokcore.component.provideAdapter,
             args=(factory, None, provides, name),
             )
         return True
@@ -78,7 +78,7 @@ class SubscriptionGrokker(martian.ClassGrokker):
     def execute(self, factory, config, context, provides, name, **kw):
         config.action(
             discriminator=None,
-            callable=component.provideSubscriptionAdapter,
+            callable=grokcore.component.provideSubscriptionAdapter,
             args=(factory, (context,), provides),
             )
         return True
@@ -98,7 +98,7 @@ class MultiSubscriptionGrokker(martian.ClassGrokker):
 
         config.action(
             discriminator=None,
-            callable=component.provideSubscriptionAdapter,
+            callable=grokcore.component.provideSubscriptionAdapter,
             args=(factory, adapts, provides),
             )
         return True
@@ -122,7 +122,7 @@ class GlobalUtilityGrokker(martian.ClassGrokker):
 
         config.action(
             discriminator=('utility', provides, name),
-            callable=component.provideUtility,
+            callable=grokcore.component.provideUtility,
             args=(factory, provides, name),
             )
         return True
@@ -149,7 +149,7 @@ class ImplementerDecoratorGrokker(martian.GlobalGrokker):
             name = getattr(function, '__component_name__', u"")
             config.action(
                 discriminator=('adapter', interfaces, function.__implemented__, name),
-                callable=component.provideAdapter,
+                callable=grokcore.component.provideAdapter,
                 args=(function, interfaces, function.__implemented__, name),
                 )
         return True
@@ -180,7 +180,7 @@ class GlobalUtilityDirectiveGrokker(martian.GlobalGrokker):
 
             config.action(
                 discriminator=('utility', provides, name),
-                callable=component.provideUtility,
+                callable=grokcore.component.provideUtility,
                 args=(obj, provides, name),
                 )
 
@@ -196,15 +196,13 @@ class GlobalAdapterDirectiveGrokker(martian.GlobalGrokker):
                 bound = grokcore.component.provides.bind(default=None)
                 provides = bound.get(factory)
             if adapts is None:
-                adapts = getattr(factory, '__component_adapts__', None)
-                if adapts is None:
-                    adapts = grokcore.component.context.bind().get(factory)
+                adapts = (grokcore.component.context.bind().get(module),)
             if name is None:
                 name = grokcore.component.name.bind().get(factory)
 
             config.action(
                 discriminator=('adapter', adapts, provides, name),
-                callable=component.provideAdapter,
+                callable=grokcore.component.provideAdapter,
                 args=(factory, adapts, provides, name),
                 )
 
@@ -229,17 +227,17 @@ class SubscriberDirectiveGrokker(martian.GlobalGrokker):
             if provides is None:
                 config.action(
                     discriminator=None,
-                    callable=component.provideHandler,
+                    callable=grokcore.component.provideHandler,
                     args=(factory, subscribed))
             else:
                 config.action(
                     discriminator=None,
-                    callable=component.provideSubscriptionAdapter,
+                    callable=grokcore.component.provideSubscriptionAdapter,
                     args=(factory, subscribed, provides))
 
             for iface in subscribed:
                 config.action(
                     discriminator=None,
-                    callable=zope.component.interface.provideInterface,
+                    callable=grokcore.component.provideInterface,
                     args=('', iface))
         return True
