@@ -5,7 +5,8 @@ Multiple models lead to ambiguity:
   Traceback (most recent call last):
     ...
   GrokError: Multiple possible contexts for
-  <class 'grokcore.component.tests.adapter.multiple.Home'>, please use grok.context.
+  <class 'grokcore.component.tests.adapter.multiple.Home'>, please use the
+  'context' directive.
 
 """
 import grokcore.component as grok
