@@ -5,7 +5,8 @@ If no model can be found in the module, we get an error:
   Traceback (most recent call last):
     ...
   GrokError: No module-level context for
-  <class 'grokcore.component.tests.adapter.nomodel.Home'>, please use the 'context' directive.
+  <class 'grokcore.component.tests.adapter.nomodel.Home'>, please use the
+  'context' directive.
 
 """
 import grokcore.component as grok
