@@ -5,6 +5,7 @@ still perform actions on the grokked components.
 Here we define AlphaGrokker which has higher priority than BetaGrokker but does
 not block BetaGrokker from picking up the same component::
 
+    >>> import grokcore.component as grok
     >>> grok.testing.grok(__name__)
 
 In the fixture there is AlphaBetaSub that inherits from both Alpha and Beta.
@@ -15,7 +16,7 @@ Thus, both Grokkers are executed, with AlphaGrokker coming before BetaGrokker::
     beta
 
 """
-import grokcore.component as grok
+import martian
 
 
 class Alpha(object):
@@ -24,16 +25,16 @@ class Alpha(object):
 class Beta(object):
     pass
 
-class AlphaGrokker(grok.ClassGrokker):
-    component_class = Alpha
-    priority = 1 # we need to go before BetaGrokker
+class AlphaGrokker(martian.ClassGrokker):
+    martian.component(Alpha)
+    martian.priority(1) # we need to go before BetaGrokker
 
     def grok(self, name, factory, module_info, config, **kw):
         print "alpha"
         return True
 
-class BetaGrokker(grok.ClassGrokker):
-    component_class = Beta
+class BetaGrokker(martian.ClassGrokker):
+    martian.component(Beta)
 
     def grok(self, name, factory, module_info, config, **kw):
         print "beta"
