@@ -2,7 +2,7 @@ import martian
 from component import Alpha
 
 class AlphaGrokker(martian.ClassGrokker):
-    component_class = Alpha
+    martian.component(Alpha)
 
     def grok(self, name, factory, module_info, **kw):
         print "alpha"
