@@ -5,7 +5,7 @@ be done by definition order.
 
   >>> components = [First(), Second(), Third(), Fourth(), Fifth()]
 
-  >>> from grokcore.component.util import sort_components
+  >>> from grokcore.component import sort_components
   >>> sort_components(components)
   [<...First object at ...>,
    <...Second object at ...>,
